@@ -3,7 +3,8 @@ from pyrfc import ABAPApplicationError, ABAPRuntimeError, LogonError, Communicat
 
 from .connection import SAPConnection
 from .exceptions import SAPException
-from typing import List, Generator
+from typing import List, Generator, Any
+import json
 
 
 class SAP:
@@ -23,6 +24,7 @@ class SAP:
                     table: str,
                     columns: List[str],
                     where: str = None,
+                    humanized_columns: List[str] = None,
                     page_size: int = 1000) -> Generator[pd.DataFrame, None, None]:
         fields = []
         where_clause = []
@@ -46,7 +48,10 @@ class SAP:
                                          ROWSKIPS=start,
                                          ROWCOUNT=limit)
                 connection.close()
-                yield self._to_dataframe(result['DATA'], columns)
+                data = self._to_dataframe(result['DATA'], columns)
+                if humanized_columns:
+                    data.columns = humanized_columns
+                yield data
                 if len(result['DATA']) < page_size:
                     break
                 page += 1
@@ -62,7 +67,8 @@ class SAP:
                       columns: List[str],
                       page: int,
                       where: str = None,
-                      page_size: int = 1000) -> Generator[pd.DataFrame, None, None]:
+                      humanized_columns: List[str] = None,
+                      page_size: int = 1000) -> Any:
         fields = []
         where_clause = []
         df = pd.DataFrame(columns=columns)
@@ -83,7 +89,10 @@ class SAP:
                                      ROWSKIPS=start,
                                      ROWCOUNT=limit)
             connection.close()
-            return self._to_dataframe(result['DATA'], columns).to_json(orient='records', force_ascii=False)
+            data = self._to_dataframe(result['DATA'], columns)
+            if humanized_columns:
+                data.columns = humanized_columns
+            return json.loads(data.to_json(orient='records', force_ascii=False))
         except CommunicationError:
             raise SAPException('Could not connect to server')
         except LogonError:
